@@ -226,14 +226,14 @@ class Release:
             )
 
     def _get_releases_since(self, threshold):
-        releases = self._repo.get_releases()
+        releases = self._repo.get_releases().get_page(0)
 
         return [
             rel for rel in releases if semver.compare(threshold, rel.tag_name) == -1
         ][0:4]
 
     def _get_releases_before(self, threshold):
-        releases = self._repo.get_releases()
+        releases = self._repo.get_releases().get_page(0)
 
         return [
             rel for rel in releases if semver.compare(threshold, rel.tag_name) == 1
