@@ -176,7 +176,12 @@ class GitHandler:
                 stdout=subprocess.PIPE,
             )
 
-            return output.stdout.decode("utf-8").strip("\n").strip().strip("origin/")
+            return (
+                output.stdout.decode("utf-8")
+                .strip("\n")
+                .strip()
+                .removeprefix("origin/")
+            )
         except CalledProcessError:
             return ""
 
